@@ -7,5 +7,5 @@ observation = env.reset()
 done = False
 
 while not done:
-    observation, reward, done = env.step(random.randint(0, 3))
+    observation, reward, done, info = env.step(random.randint(0, 3))
     env.render()
